Module wolfram_expr::symbol

source ·
Representation of Wolfram Language symbols.

This module provides four primary types:

These types are used for storing a string value that has been validated to conform to the syntax of Wolfram Language symbols and contexts.

In addition to the previous types, which own their string value, types are provided that can be used to validate a borrowed &str value, without requiring another allocation:

Structs

Wolfram Language context.
Borrowed string containing a valid context.
Context begining with a `.
Wolfram Language symbol.
The identifier portion of a symbol. This contains no context marks (‘`’).
Borrowing string containing a valid symbol name.
Borrowed string containing a valid symbol.